@@ -1,6 +1,6 @@
 package rig::cmd::cpan;
 BEGIN {
-  $rig::cmd::cpan::VERSION = '0.01_01';
+  $rig::cmd::cpan::VERSION = '0.01_02';
 }
 use strict;
 use CPAN;
@@ -10,11 +10,12 @@ use rig '-load';
 sub run {
     my $self = shift;
     my $parser = $rig::opts{parser};
-    my $data = $parser->rc_parse;
+    my $data = $parser->parse;
     #return unless ref $data eq 'HASH';
     for my $task ( keys %$data ) {
         print "Loaded $task...\n";
-        for my $module ( @{ $data->{$task} } ) {
+		next unless exists $data->{$task}->{use};
+        for my $module ( @{ $data->{$task}->{use} } ) {
             ref $module eq 'HASH' and $module = (keys %$module)[0];
             print "Installing $module...\n";
             $self->_install_module($module);
@@ -36,7 +37,7 @@ rig::cmd::cpan - Command to install a rig with the cpan command line
 
 =head1 VERSION
 
-version 0.01_01
+version 0.01_02
 
 =head1 SYNOPSYS
 
